﻿using System;
using RomeScriptInterfaces;
using Scripts;

namespace Scripts
{
    [Serializable]
    public class AisleOfPlentyNovice : ScriptServer.IScript
    {
        private TMilitaryAI mMilitaryAI = null;
        private InvasionSetup[] mInvasions;
       
        private enum EventList : uint
        {    
            kScriptStart,
            kLoadState,
            kScriptDone,          // We'll check for this at the end to set ScriptDone to true


        }
        // for our messaging
        private String msgTitle;
        private String msgText;
        private String msgSound;
        private String msgWarn;
        private EventList scriptState = EventList.kScriptStart;
        private EventList loadState = EventList.kScriptStart;

     
        //plaza id, needed to disable plazas
        private Int32 mUIIDPlaza1 = IDMaker.FromString("PLAZA1");
        private Int32 mUIIDPlaza2 = IDMaker.FromString("PLAZA2");
        private Int32 mUIIDPlaza3 = IDMaker.FromString("PLAZA3");

        //switches for events
        private bool b4500Message = false;
        private bool b1000DebtMessage = false;
        private bool bSaveMessage = false;
        
        
        // local instance of the Toolset (support functions from Tools.cs)
        // We have to run its Init() for it to work!
        private Toolset Tools;
        //
               // This is the main script loop
        public void Run(object gameInterface)
        {
            IGameQueryInterface gameQueryInterface = (IGameQueryInterface)gameInterface;
            switch (gameQueryInterface.RunReason)
            {
                case RunReason.kTick:
                    OnTick(gameQueryInterface);
                    break;

                case RunReason.kOnBeginScenario:
                    OnBeginScenario(gameQueryInterface);
                    break;

                case RunReason.kOnInvasionArrival:
                    OnInvasionArrival(gameQueryInterface);
                    break;

                case RunReason.kOnCohortTargetDestroyed:
                    OnCohortTargetDestroyed(gameQueryInterface);
                    break;

                case RunReason.kOnLoadScenario:
                    OnScenarioLoad(gameQueryInterface);
                    break;
            }
        }

        void OnTick(IGameQueryInterface game)
        {
            
            CheckTreasury(game);
            CheckPopulation(game);
            CheckForSave(game);
            mMilitaryAI.Update(game, 0.1);   

           
            
            
        }
           
        
         
     
        void OnScenarioLoad(IGameQueryInterface game)
        {
            {
                
                // lock plaza build buttons
                game.LockUIControl(mUIIDPlaza1, Toolset.MainGameFormID);
                game.LockUIControl(mUIIDPlaza2, Toolset.MainGameFormID);
                game.LockUIControl(mUIIDPlaza3, Toolset.MainGameFormID);
            }


            game.ScriptDone = true;
        }
        void CheckPopulation(IGameQueryInterface game)
        {
            int numPopulation = 0;
            game.GetPopulation(out numPopulation);
            {
            if ((!b4500Message) && (numPopulation >= 4500))
            {
                // send warning message if population exceeds 4500
     
                    msgTitle = "EVENT_Population_4500_Title";
                    msgText = "EVENT_Population_4500_Message";
                    msgSound = "message1.mp3";
                    game.SendGameMessage(
                         (uint)MessageCategory.kLocalEventMessage,
                         (uint)MessageDisplay.kMessageDisplaySignificant,
                         ref msgTitle, ref msgText, ref msgSound);
                    b4500Message = true;
                   }
            }
            //open defeat trade route
            if (numPopulation >= 5001)
            {
                game.OpenTradeRoute(0);
            }
        }
      void CheckTreasury(IGameQueryInterface game)
        {
            int numTreasury = 0;
            game.GetCityFunds(out numTreasury);
            {
                if ((!b1000DebtMessage) && (numTreasury <= -1000))
                {
                    //Send Warning Message if debt exceeds 1000
                   msgTitle = "EVENT_Debt1000_Title";
                   msgText = "EVENT_Debt1000_Message";
                   msgSound = "message1.mp3";
                   game.SendGameMessage(
                       (uint)MessageCategory.kLocalEventMessage,
                        (uint)MessageDisplay.kMessageDisplaySignificant,
                       ref msgTitle, ref msgText, ref msgSound);
                   b1000DebtMessage = true;
                }
            }
          // open defeat trade route
            if (numTreasury <= -2001)
            {
                game.OpenTradeRoute(0);
                }
          //open million trade route
                if (numTreasury >= 1000000)
                {
                    game.OpenTradeRoute(13);
                }
        }
        void CheckForSave(IGameQueryInterface game)
        {
            //save game messages

            //Tools.Init(game);

            if ((game.GameTime >= 890000) && (game.GameTime <= 892000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 1850000) && (game.GameTime <= 1852000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 2810000) && (game.GameTime <= 2812000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 3770000) && (game.GameTime <= 3772000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 4730000) && (game.GameTime <= 4732000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 5690000) && (game.GameTime <= 5692000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 6650000) && (game.GameTime <= 6652000))
            {
                bSaveMessage = true;
            }

            else if ((game.GameTime >= 7610000) && (game.GameTime <= 7612000))
            {
                bSaveMessage = true;
            }



            else if ((game.GameTime >= 8570000) && (game.GameTime <= 8572000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 9530000) && (game.GameTime <= 9532000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 10490000) && (game.GameTime <= 10492000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 11450000) && (game.GameTime <= 11452000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 12410000) && (game.GameTime <= 12412000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 13370000) && (game.GameTime <= 13372000))
            {
                bSaveMessage = true;
            }


            else if ((game.GameTime >= 14330000) && (game.GameTime <= 14332000))
            {
                bSaveMessage = true;
            }

            else if ((game.GameTime >= 15290000) && (game.GameTime <= 15292000))
            {
                bSaveMessage = true;
            }
            
            if (bSaveMessage == true)
            {
                msgWarn = "EVENT_SaveGame_Message";
                msgSound = "message1.mp3";
                game.SendWarningMessage(ref msgWarn, ref msgSound);
                bSaveMessage = false;
            }
        }
        
           void OnBeginScenario(IGameQueryInterface game)
        {
          
           
            // tiny gaul raid
            //mInvasions = new InvasionSetup[8];

           // mInvasions[0] = new InvasionSetup("raid1", sInvasionFactions.kGaul,
           //     eInvasionType.kRaid, 10000, 100, 0);
           // mInvasions[0].AddCohort(sCohortDbIDs.kGaul_Lt, 1, 4, 4);
            //mInvasions[0].AddCohort(sCohortDbIDs.kGaul_Aux, 2, 1, 1);
          //  mInvasions[0].CreateInvasion(game, 0, 0);

            // very small gaul raid
         //   mInvasions[1] = new InvasionSetup("raid2", sInvasionFactions.kGaul,
        //        eInvasionType.kRaid, 20000, 140, 0);
        //    mInvasions[1].AddCohort(sCohortDbIDs.kGaul_Hvy, 1, 4, 4);
       //     mInvasions[1].CreateInvasion(game, 1, 0);

            // small gaul raid
        //    mInvasions[2] = new InvasionSetup("raid3", sInvasionFactions.kGaul,
        //        eInvasionType.kRaid, 30000, 180, 0);
       //     mInvasions[2].AddCohort(sCohortDbIDs.kGaul_Lt, 1, 4, 4);
       //     mInvasions[2].AddCohort(sCohortDbIDs.kGaul_Aux, 1, 4, 4);
       //     mInvasions[2].CreateInvasion(game, 2, 0);

            // small gaul raid 
        //    mInvasions[3] = new InvasionSetup("raid4", sInvasionFactions.kGaul,
         //       eInvasionType.kRaid, 40000, 220, 0);
       //     mInvasions[3].AddCohort(sCohortDbIDs.kGaul_Lt, 1, 4, 4);
       //     mInvasions[3].AddCohort(sCohortDbIDs.kGaul_Hvy, 1, 4, 4);
       //     mInvasions[3].CreateInvasion(game, 3, 0);

            // small gaul raid
      //      mInvasions[4] = new InvasionSetup("raid5", sInvasionFactions.kGaul,
      //          eInvasionType.kRaid, 50000, 260, 0);
      ////      mInvasions[4].AddCohort(sCohortDbIDs.kGaul_Lt, 1, 4, 4);
      //      mInvasions[4].AddCohort(sCohortDbIDs.kGaul_Aux, 1, 4, 4);
      //      mInvasions[4].AddCohort(sCohortDbIDs.kGaul_Hvy, 1, 4, 4);
     //       mInvasions[4].CreateInvasion(game, 4, 0);

            // small gaul raid
     //       mInvasions[5] = new InvasionSetup("raid6", sInvasionFactions.kGaul,
     //           eInvasionType.kRaid, 60000, 300, 0);
     //       mInvasions[5].AddCohort(sCohortDbIDs.kGaul_Lt, 1, 4, 4);
     //       mInvasions[5].AddCohort(sCohortDbIDs.kGaul_Aux, 1, 4, 4);
     //       mInvasions[5].AddCohort(sCohortDbIDs.kGaul_Cav, 1, 4, 4);
    //        mInvasions[5].AddCohort(sCohortDbIDs.kGaul_Hvy, 1, 4, 4);
   //         mInvasions[5].CreateInvasion(game, 5, 0);

            // small gaul raid
    //        mInvasions[6] = new InvasionSetup("raid7", sInvasionFactions.kGaul,
   //             eInvasionType.kRaid, 70000, 350, 0);
  //          mInvasions[6].AddCohort(sCohortDbIDs.kGaul_Lt, 2, 4, 5);
    //        mInvasions[6].AddCohort(sCohortDbIDs.kGaul_Aux, 1, 4, 5);
    //        mInvasions[6].AddCohort(sCohortDbIDs.kGaul_Cav, 1, 4, 5);
    //        mInvasions[6].AddCohort(sCohortDbIDs.kGaul_Hvy, 1, 4, 5);
    //        mInvasions[6].CreateInvasion(game, 6, 0);

   //         // gaul raid
    //        mInvasions[7] = new InvasionSetup("raid8", sInvasionFactions.kGaul,
    //           eInvasionType.kRaid, 80000, 400, 0);
    //        mInvasions[7].AddCohort(sCohortDbIDs.kGaul_Hvy, 5, 4, 4);
            //mInvasions[7].AddCohort(sCohortDbIDs.kGaul_Aux, 2, 1, 1);
    ///        mInvasions[7].CreateInvasion(game, 7, 6);
           
    //        mMilitaryAI = new TMilitaryAI(game);

            game.ScriptDone = true;
        }
            // Initialization needed on scenario load (from .scn and .c4s both)
        // specifically, make sure the ScriptDone flag is set (for older save games)
      
            void OnInvasionArrival(IGameQueryInterface game)
        {
            // let's find out which invasion we are...
            foreach (InvasionSetup inv in mInvasions)
            //
            if (game.RunInvasion == inv.GetInvasionName())
            {
                // hook into military AI
                eInvasionType invType = inv.GetInvasionType();
                mMilitaryAI.InvasionBegin(invType, game);
                break;
            }
        }


        void OnCohortTargetDestroyed(IGameQueryInterface game)
        {
            // see what we should be doing next
            String nextOrders = mMilitaryAI.InvasionTargetDestroyed(game.RunCohortID, game);
            game.SetCohortOrders(game.RunCohortID, ref nextOrders);
        }

}

    }

